<?php

namespace MotoPress\Appointment\AdminPages\Edit;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class EditPostPage
{
    /**
     * @var string
     *
     * @since 1.0
     */
    protected $postType;

    /**
     * @var string Like the post type, but without the prefix.
     *
     * @since 1.0
     */
    protected $entityType;

    /**
     * @var string
     *
     * @since 1.0
     */
    protected $capability = 'edit_post';

    /**
     * @param string $postType
     *
     * @since 1.0
     */
    public function __construct($postType)
    {
        $this->postType = $postType;
        $this->entityType = mpa_unprefix($postType);

        // Global variable $typenow is not ready on action 'admin_init'. Wait
        // until the real page loads
        add_action('load-post.php', [$this, 'onLoad'], 15);
        add_action('load-post-new.php', [$this, 'onLoad'], 15);
    }

    /**
     * @access protected
     *
     * @since 1.0
     */
    public function onLoad()
    {
        if (!$this->isCurrentPage()) {
            return;
        }

        $this->addActions();

        /** @since 1.0 */
        do_action("mpa_edit_{$this->entityType}_page_loaded");
    }

    /**
     * @since 1.0
     */
    protected function addActions()
    {
        add_action('admin_enqueue_scripts', [$this, 'enqueueScripts']);
    }

    /**
     * @access protected
     *
     * @since 1.0
     */
    public function enqueueScripts()
    {
        mpa_assets()->enqueueBundle('mpa-edit-post');
    }

    /**
     * @return bool
     *
     * @since 1.0
     */
    public function isCurrentPage()
    {
        return $this->isCurrentAddNewPage() || $this->isCurrentEditPage();
    }

    /**
     * @return bool
     *
     * @global string $pagenow
     * @global string $typenow
     *
     * @since 1.0
     */
    public function isCurrentEditPage()
    {
        global $pagenow, $typenow;

        return is_admin() && $pagenow === 'post.php' && $typenow === $this->postType;
    }

    /**
     * @return bool
     *
     * @global string $pagenow
     * @global string $typenow
     *
     * @since 1.0
     */
    public function isCurrentAddNewPage()
    {
        global $pagenow, $typenow;

        return is_admin() && $pagenow === 'post-new.php' && $typenow === $this->postType;
    }
}
