<?php

namespace MotoPress\Appointment\AdminPages\Manage;

use MotoPress\Appointment\Entities\Booking;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class ManageBookingsPage extends ManagePostsPage
{
    /**
     * @since 1.0
     */
    protected function enqueueScripts()
    {
        mpa_assets()->enqueueStyle('mpa-manage-posts');
    }

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function customColumns()
    {
		$isMultibooking = mpapp()->settings()->isMultibookingEnabled();

        return [
			'status'	=> esc_html__('Status', 'motopress-appointment'),
			'customer'	=> esc_html__('Customer', 'motopress-appointment'),
			'price'		=> esc_html__('Price', 'motopress-appointment'),
			'services'	=> $isMultibooking ? esc_html__('Services', 'motopress-appointment') : esc_html__('Service', 'motopress-appointment'),
			'employees'	=> $isMultibooking ? esc_html__('Employees', 'motopress-appointment') : esc_html__('Employee', 'motopress-appointment'),
			'time'		=> esc_html__('Time', 'motopress-appointment'),
			'people'	=> esc_html__('Clients', 'motopress-appointment'),
        ];
    }

    /**
     * @param string $columnName
     * @param Booking $entity
     *
     * @since 1.0
     */
    protected function displayValue($columnName, $entity)
    {
        switch ($columnName) {
            case 'status':
                echo '<span class="column-status-' . esc_attr($entity->status) . '">' . esc_html( mpa_get_status_label($entity->status) ) . '</span>';
                break;

            case 'customer':
                $customer = $entity->customer;
                $customerInfo = [];

                if (!empty($customer->name)) {
                    $customerInfo[] = $customer->name;
                }

                if (!empty($customer->email)) {
                    $customerInfo[] = '<a href="mailto:' . esc_attr($customer->email) . '">' . $customer->email . '</a>';
                }

                if (!empty($customer->phone)) {
                    $customerInfo[] = '<a href="tel:' . esc_attr($customer->phone) . '">' . $customer->phone . '</a>';
                }

                if (!empty($customerInfo)) {
                    echo wp_kses_post( implode('<br>', $customerInfo ) );
                } else {
                    echo esc_html( mpa_tmpl_placeholder() );
                }

                break;

            case 'price': echo wp_kses_post( mpa_tmpl_price($entity->totalPrice) ); break;

			case 'services':
				// Pull employee names
				$services = array_map(
					function ($reservation) {
						$serviceName = get_the_title($reservation->serviceId);
						return $serviceName ?: mpa_tmpl_placeholder();
					},
					$entity->reservations
				);

				if (!empty($services)) {
					echo wp_kses_post( implode('<br>', $services) );
				} else {
					echo esc_html( mpa_tmpl_placeholder() );
				}

                break;

			case 'employees':
				// Pull employee names
				$employees = array_map(
					function ($reservation) {
						$employeeName = get_the_title($reservation->employeeId);
						return $employeeName ?: mpa_tmpl_placeholder();
					},
					$entity->reservations
				);

				if (!empty($employees)) {
					echo wp_kses_post( implode('<br>', $employees) );
				} else {
					echo esc_html( mpa_tmpl_placeholder() );
				}

				break;

			case 'time':
				// Pull dates
				$dates = array_map(
					function ($reservation) {
						$date = mpa_format_date($reservation->date);
						$time = $reservation->serviceTime->toString();

						return "{$date}, {$time}";
					},
					$entity->reservations
				);

				if (!empty($dates)) {
					echo wp_kses_post( implode('<br>', $dates) );
				} else {
					echo esc_html( mpa_tmpl_placeholder() );
				}

				break;

			case 'people':
				$people = array_map(
					function ($reservation) { return $reservation->capacity; },
					$entity->reservations
				);

				if (!empty($people)) {
					echo wp_kses_post( implode('<br>', $people) );
				} else {
					echo esc_html( mpa_tmpl_placeholder() );
				}

				break;
        }
    }
}
