<?php

namespace MotoPress\Appointment\Bundles;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 *
 * @todo Make Flatpickr part of the other bundles.
 */
class AssetsBundle
{
    /**
     * @var array
     *
     * @since 1.0
     * @since 1.2 added "mpa-edit-category" script.
     * @since 1.2.1 added "mpa-admin" script.
     */
    protected $scripts = [
        // Use .min.js version of the file by default if there is a minified
        // version of the script; otherwise - use .js notation
        'global' => [
            // Handle => [$file, $dependencies = [], $version = '', $inFooter = true]
            'mpa-flatpickr' => ['vendors/flatpickr-4.6.3/dist/flatpickr.min.js', [], \MotoPress\Appointment\FLATPICKR_VERSION],
            'mpa-spectrum'  => ['vendors/spectrum-colorpicker-1.8.0/dist/spectrum.min.js', ['jquery'], \MotoPress\Appointment\SPECTRUM_VERSION]
        ],
        'admin'  => [
            'mpa-admin'            => ['assets/js/admin.min.js'],
            'mpa-edit-post'        => ['assets/js/edit-post.min.js', ['jquery', 'wp-i18n', 'wp-api-request', 'mpa-flatpickr']],
            'mpa-edit-category'    => ['assets/js/edit-category.min.js', ['jquery', 'wp-media']],
            'mpa-manage-posts'     => ['assets/js/manage-posts.min.js', ['jquery']],
            'mpa-settings-page'    => ['assets/js/settings-page.min.js', ['jquery', 'wp-api-request']],
            'mpa-gutenberg-blocks' => ['assets/js/gutenberg-blocks.min.js', ['wp-i18n', 'wp-editor', 'wp-element', 'wp-blocks', 'wp-components']],
        ],
        'public' => [
            'mpa-public'            => ['assets/js/public.min.js', ['jquery', 'wp-i18n', 'wp-api-request', 'mpa-flatpickr']],
            'mpa-elementor-widgets' => ['assets/js/elementor-widgets.min.js', ['jquery', 'wp-i18n', 'wp-api-request', 'mpa-flatpickr']],
            'mpa-divi-modules'      => ['assets/js/divi-modules.min.js', [ 'jquery', 'customize-preview' ]],
        ]
    ];

    /**
     * @var array
     *
     * @since 1.0
     * @since 1.2 added "mpa-edit-category" style.
     * @since 1.2.1 added "mpa-admin" style.
     */
    protected $styles = [
        // Use .min.css version of the file by default if there is a minified
        // version of the stylesheet; otherwise - use .css notation
        'global' => [
            // Handle => [$file, $dependencies = [], $version = '', $media = 'all']
            'mpa-flatpickr' => ['vendors/flatpickr-4.6.3/dist/flatpickr.min.css', [], \MotoPress\Appointment\FLATPICKR_VERSION],
            'mpa-spectrum'  => ['vendors/spectrum-colorpicker-1.8.0/dist/themes/default.css', [], \MotoPress\Appointment\SPECTRUM_VERSION]
        ],
        'admin'  => [
            'mpa-admin'            => ['assets/css/admin.min.css'],
            'mpa-edit-post'        => ['assets/css/edit-post.min.css', ['mpa-flatpickr']],
            'mpa-edit-category'    => ['assets/css/edit-category.min.css'],
            'mpa-manage-posts'     => ['assets/css/manage-posts.min.css'],
            'mpa-settings-page'    => ['assets/css/settings-page.min.css'],
            'mpa-gutenberg-blocks' => ['assets/css/public.min.css'],
        ],
        'public' => [
            'mpa-public' => ['assets/css/public.min.css', ['mpa-flatpickr']]
        ]
    ];

    /**
     * @return array Array of [Handle => [$file, $dependencies = [],
     *     $version = '', $inFooter = true]].
     *
     * @since 1.0
     */
    public function getAdminScripts()
    {
        $scripts = array_merge($this->scripts['global'], $this->scripts['admin']);
        /** @since 1.0 */
        $scripts = apply_filters('mpa_admin_scripts', $this->filterAssets($scripts));

        return $scripts;
    }

    /**
     * @return array Array of [Handle => [$file, $dependencies = [],
     *     $version = '', $inFooter = true]].
     *
     * @since 1.0
     */
    public function getPublicScripts()
    {
        $scripts = array_merge($this->scripts['global'], $this->scripts['public']);
        /** @since 1.0 */
        $scripts = apply_filters('mpa_public_scripts', $this->filterAssets($scripts));

        return $scripts;
    }

    /**
     * @return array Array of [Handle => [$file, $dependencies = [],
     *     $version = '', $media = 'all']].
     *
     * @since 1.0
     */
    public function getAdminStyles()
    {
        $styles = array_merge($this->styles['global'], $this->styles['admin']);
        /** @since 1.0 */
        $styles = apply_filters('mpa_admin_styles', $this->filterAssets($styles));

        return $styles;
    }

    /**
     * @return array Array of [Handle => [$file, $dependencies = [],
     *     $version = '', $media = 'all']].
     *
     * @since 1.0
     */
    public function getPublicStyles()
    {
        $styles = array_merge($this->styles['global'], $this->styles['public']);
        /** @since 1.0 */
        $styles = apply_filters('mpa_public_styles', $this->filterAssets($styles));

        return $styles;
    }

    /**
     * @param array $assets
     * @return array
     *
     * @since 1.0
     */
    protected function filterAssets($assets)
    {
        foreach ($assets as &$args) {
            $args[0] = mpa_filter_asset($args[0]);
        }

        unset($args);

        return $assets;
    }
}
