<?php
/**
 * Class: AppointmentFormWidget
 * Name: Appointment Form
 * Slug: appointment-form
 */

namespace MotoPress\Appointment\Elementor\Widgets;

use \Elementor\Controls_Manager;
use \Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class AppointmentFormWidget extends Widget_Base
{

    public function get_style_depends()
    {

        return [ 'mpa-public' ];
    }

    public function get_script_depends()
    {

        return [ 'mpa-public', 'mpa-elementor-widgets' ];
    }

    public function get_name()
    {

        return 'appointment-form';
    }

	public function get_title()
	{

		return esc_html__( 'Appointment Form', 'motopress-appointment' );
	}

	public function get_keywords()
	{

		return [ 'appointment' ];
	}

	public function get_icon()
	{

		return 'eicon-single-post';
	}

	public function get_categories()
	{

		return [ 'mpa-elementor-widgets' ];
    }

    protected function _register_controls()
    {

		$controls     = $this;
        $unselectedId = [ 0  => esc_html__( '— Unselected —', 'motopress-appointment' ) ];

        $controls->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Settings', 'motopress-appointment' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

            $controls->add_control(
                'show_category',
                [
                    'label'        => esc_html__( 'Show Category?', 'motopress-appointment' ),
                    'description'  => esc_html__( 'Show the service category field in the form.', 'motopress-appointment' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'return_value' => 'true',
                    'default'      => 'true',
                ]
            );

            $controls->add_control(
                'show_location',
                [
                    'label'        => esc_html__( 'Show Location?', 'motopress-appointment' ),
                    'description'  => esc_html__( 'Show the location field in the form.', 'motopress-appointment' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'return_value' => 'true',
                    'default'      => 'true',
                ]
            );

            $controls->add_control(
                'show_employee',
                [
                    'label'        => esc_html__( 'Show Employee?', 'motopress-appointment' ),
                    'description'  => esc_html__( 'Show the employee field in the form.', 'motopress-appointment' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'return_value' => 'true',
                    'default'      => 'true',
                ]
            );

            $controls->add_control(
                'label_category',
                [
                    'label'       => esc_html__( 'Category Field Label', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( 'Service Category', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the service category field.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'label_service',
                [
                    'label'       => esc_html__( 'Service Field Label', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( 'Service', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the service field.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'label_location',
                [
                    'label'       => esc_html__( 'Location Field Label', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( 'Location', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the location field.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'label_employee',
                [
                    'label'       => esc_html__( 'Employee Field Label', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( 'Employee', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the employee field.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'label_unselected',
                [
                    'label'       => esc_html__( 'Unselected Service', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( '— Select —', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the unselected service field.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'label_option',
                [
                    'label'       => esc_html__( 'Unselected Option', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => esc_html__( '— Any —', 'motopress-appointment' ),
                    'description' => esc_html__( 'Custom label for the unselected service category, location and employee fields.', 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'default_category',
                [
                    'label'       => esc_html__( 'Service Category', 'motopress-appointment' ),
                    'description' => esc_html__( 'Slug of the selected service category.', 'motopress-appointment' ),
                    'type'        => Controls_Manager::SELECT,
                    'default'     => 0,
                    'options'     => $unselectedId + mpa_get_service_categories(),
                    'separator'   => 'before'
                ]
            );

            $controls->add_control(
                'default_service',
                [
                    'label'       => esc_html__( 'Service', 'motopress-appointment' ),
                    'description' => esc_html__( 'ID of the selected service.', 'motopress-appointment' ),
                    'type'        => Controls_Manager::SELECT,
                    'default'     => 0,
                    'options'     => $unselectedId + mpa_get_services(),
                ]
            );

            $controls->add_control(
                'default_location',
                [
                    'label'       => esc_html__( 'Location', 'motopress-appointment' ),
                    'description' => esc_html__( 'ID of the selected location.', 'motopress-appointment' ),
                    'type'        => Controls_Manager::SELECT,
                    'default'     => 0,
                    'options'     => $unselectedId + mpa_get_locations(),
                ]
            );

            $controls->add_control(
                'default_employee',
                [
                    'label'       => esc_html__( 'Employee', 'motopress-appointment' ),
                    'description' => esc_html__( 'ID of the selected employee.', 'motopress-appointment' ),
                    'type'        => Controls_Manager::SELECT,
                    'default'     => 0,
                    'options'     => $unselectedId + mpa_get_employees(),
                    'separator'   => 'after'
                ]
            );

            $controls->add_control(
                'html_id',
                [
                    'label'       => esc_html__( 'HTML Anchor', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'dynamic'     => [
                        'active'  => true,
                    ],
                    'label_block' => true,
                    'description' =>  mpa_kses_link( __( 'HTML Anchor. Anchors lets you link directly to a section on a page. <a href="https://wordpress.org/support/article/page-jumps/" target="_blank">Learn more about anchors.</a>', 'motopress-appointment' ) ),
                ]
            );

            $controls->add_control(
                'html_class',
                [
                    'label'       => __( 'CSS Class(es)', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'dynamic'     => [
                        'active'  => true,
                    ],
                    'label_block' => true,
                    'description' => esc_html__( 'Additional CSS Class(es). Separate multiple classes with spaces.', 'motopress-appointment' ),
                ]
            );

        $controls->end_controls_section();
    }

    protected function render()
    {

        $attributes = $this->get_settings();
        echo mpa_shortcodes()->appointmentForm()->render( $attributes ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }

}