<?php
/**
 * Class: EmployeeContentWidget
 * Name: Employee Content
 * Slug: mpa-employee-content
 */

namespace MotoPress\Appointment\Elementor\Widgets;

use \Elementor\Controls_Manager;
use \Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class EmployeeContentWidget extends Widget_Base
{

    public function get_style_depends()
    {

        return [ 'mpa-public' ];
    }

    public function get_name()
    {

        return 'mpa-employee-content';
    }

	public function get_title()
	{

		return esc_html__( 'Employee Content', 'motopress-appointment' );
	}

	public function get_keywords()
	{

		return [ 'appointment' ];
	}

	public function get_icon()
	{

		return 'eicon-table-of-contents';
	}

	public function get_categories()
	{

		return [ 'mpa-elementor-widgets' ];
    }

    protected function _register_controls()
    {

		$controls = $this;

		$controls->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Settings', 'motopress-appointment' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

            $controls->add_control(
                'shortcode_id',
                [
                    'label'       => esc_html__( 'ID', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'description' => esc_html__( "Post ID of an employee to display content from. Note: this parameter automatically uses the current post ID when a shortcode is inside the employee's post and is required otherwise.", 'motopress-appointment' ),
                ]
            );

            $controls->add_control(
                'html_id',
                [
                    'label'       => esc_html__( 'HTML Anchor', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'dynamic'     => [
                        'active'  => true,
                    ],
                    'label_block' => true,
                    'separator'   => 'before',
                    'description' =>  mpa_kses_link( __( 'HTML Anchor. Anchors lets you link directly to a section on a page. <a href="https://wordpress.org/support/article/page-jumps/" target="_blank">Learn more about anchors.</a>', 'motopress-appointment' ) ),
                ]
            );

            $controls->add_control(
                'html_class',
                [
                    'label'       => esc_html__( 'CSS Class(es)', 'motopress-appointment' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'dynamic'     => [
                        'active'  => true,
                    ],
                    'label_block' => true,
                    'description' => esc_html__( 'Additional CSS Class(es). Separate multiple classes with spaces.', 'motopress-appointment' ),
                ]
            );

        $controls->end_controls_section();
    }

    protected function render()
    {

        $attributes         = $this->get_settings();
        $attributes[ 'id' ] = $attributes[ 'shortcode_id' ];

        echo mpa_shortcodes()->employeeContent()->render( $attributes ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }
}
