<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class BookingTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'booking';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('Booking tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
	 * @since 1.4.0 tags <code>booking_time</code> and <code>booking_buffer_time</code> are deprecated.
     */
    protected function setupTags()
    {
        $this->addTags([
            'booking_id' => [
                'description' => esc_html__('Booking ID', 'motopress-appointment')
            ],
            'booking_edit_link' => [
                'description' => esc_html__('Booking edit link', 'motopress-appointment')
            ],
            'booking_total_price' => [
                'description' => esc_html__('Booking total price', 'motopress-appointment')
            ],
            'booking_date' => [
                'description' => esc_html__('Booking date', 'motopress-appointment')
            ],
            'reservations_details' => [
                'description' => esc_html__('Reservation details', 'motopress-appointment')
            ],
            'customer_name' => [
                'description' => esc_html__('Customer name', 'motopress-appointment')
            ],
            'customer_email' => [
                'description' => esc_html__('Customer email', 'motopress-appointment')
            ],
            'customer_phone' => [
                'description' => esc_html__('Customer phone', 'motopress-appointment')
            ],
            'booking_time' => [
                'description' => esc_html__('Booking time (period)', 'motopress-appointment'),
                'deprecated'  => true,
            ],
            'booking_buffer_time' => [
                'description' => esc_html__('Booking time (with buffer time)', 'motopress-appointment'),
                'deprecated'  => true,
            ],
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        if (is_null($args['booking'])) {
            return '';
        }

        $booking  = $args['booking'];
        $customer = $booking->customer;

        switch ($tag) {
            case 'booking_id'         : return $booking->id;
            case 'booking_edit_link'  : return mpa_tmpl_edit_post_link($booking->id);
            case 'booking_total_price': return mpa_tmpl_price($booking->totalPrice);
            case 'customer_name'      : return $customer->name;
            case 'customer_email'     : return $customer->email;
            case 'customer_phone'     : return $customer->phone;

            case 'booking_date':
                return get_post_time(mpa_date_format(), false, $booking->id, true);

            case 'reservations_details':
                $details = '';

                foreach ($booking->reservations as $reservation) {
                    $details .= $tagsControl->replaceTags('{reservation_details}', ['reservation' => $reservation] + $args);
                }

                return $details;

            case 'booking_time':
                $serviceTimes = array_map(
                    function ($serviceTime) {
                        return $serviceTime->toString();
                    },
                    $booking->mapReservations('serviceTime')
                );

                return implode(', ', $serviceTimes);

            case 'booking_buffer_time':
                $bufferTimes = array_map(
                    function ($bufferTime) {
                        return $bufferTime->toString();
                    },
                    $booking->mapReservations('bufferTime')
                );

                return implode(', ', $bufferTimes);
        }

        return '';
    }
}
