<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class EmployeeTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'employee';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('Employee tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
     */
    protected function setupTags()
    {
        $this->addTags([
            'employee_id' => [
                'description' => esc_html__('Employee ID', 'motopress-appointment')
            ],
            'employee_name' => [
                'description' => esc_html__('Employee name', 'motopress-appointment')
            ],
            'employee_bio' => [
                'description' => esc_html__('Employee bio', 'motopress-appointment')
            ],
            'employee_link' => [
                'description' => esc_html__('Employee edit link', 'motopress-appointment')
            ]
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        if (is_null($args['reservation'])) {
            return '';
        }

        $reservation = $args['reservation'];
        $employee = mpa_get_employee($reservation->employeeId);

        if (is_null($employee)) {
            return '';
        }

        switch ($tag) {
            case 'employee_id'  : return $employee->id;
            case 'employee_name': return $employee->name;
            case 'employee_bio' : return $employee->bio;
            case 'employee_link': return mpa_tmpl_edit_post_link($employee->id);
        }

        return '';
    }
}
