<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class GeneralTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'general';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('General tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
     */
    protected function setupTags()
    {
        $this->addTags([
            'appointment' => [
                'description' => esc_html__('The plugin name', 'motopress-appointment')
            ],
            'site_title' => [
                'description' => esc_html__('Site title (set in Settings > General)', 'motopress-appointment')
            ],
            'site_link' => [
                'description' => esc_html__('Site address (URL)', 'motopress-appointment')
            ]
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        switch ($tag) {
            case 'appointment': return mpa_name();
            case 'site_title' : return $this->siteTitle();
            case 'site_link'  : return mpa_tmpl_link(home_url(), $this->siteTitle());
        }

        return '';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    protected function siteTitle()
    {
        return wp_specialchars_decode(get_bloginfo('name'), ENT_QUOTES);
    }
}
