<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class LocationTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'location';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('Location tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
     */
    protected function setupTags()
    {
        $this->addTags([
            'location_id' => [
                'description' => esc_html__('Location ID', 'motopress-appointment')
            ],
            'location_name' => [
                'description' => esc_html__('Location name', 'motopress-appointment')
            ],
            'location_description' => [
                'description' => esc_html__('Location description', 'motopress-appointment')
            ],
            'location_categories' => [
                'description' => esc_html__('Location categories', 'motopress-appointment')
            ],
            'location_link' => [
                'description' => esc_html__('Location edit link', 'motopress-appointment')
            ]
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        if (is_null($args['reservation'])) {
            return '';
        }

        $reservation = $args['reservation'];
        $location = mpa_get_location($reservation->locationId);

        if (is_null($location)) {
            return '';
        }

        switch ($tag) {
            case 'location_id'         : return $location->id;
            case 'location_name'       : return $location->name;
            case 'location_description': return $location->info;
            case 'location_categories' : return implode(', ', mpa_get_location_categories($location->id, 'name'));
            case 'location_link'       : return mpa_tmpl_edit_post_link($location->id);
        }

        return '';
    }
}
