<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * We don't use this class directly, but as a part of AdminReservationTagsGroup
 * and CustomerReservationTagsGroup. So see that classes also.
 *
 * @since 1.1.0
 */
class ReservationTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'reservation';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('Reservation tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
     */
    protected function setupTags()
    {
        $this->addTags([
            'reservation_id' => [
                'description' => esc_html__('Reservation ID', 'motopress-appointment')
            ],
            'reservation_price' => [
                'description' => esc_html__('Reservation price', 'motopress-appointment')
            ],
            'reservation_date' => [
                'description' => esc_html__('Reservation date', 'motopress-appointment')
            ],
            'reservation_time' => [
                'description' => esc_html__('Reservation time (period)', 'motopress-appointment')
            ],
            'reservation_buffer_time' => [
                'description' => esc_html__('Reservation time (with buffer time)', 'motopress-appointment')
            ],
            'start_time' => [
                'description' => esc_html__('Start time', 'motopress-appointment')
            ],
            'end_time' => [
                'description' => esc_html__('End time', 'motopress-appointment')
            ],
            'start_buffer_time' => [
                'description' => esc_html__('Start time (with buffer time)', 'motopress-appointment')
            ],
            'end_buffer_time' => [
                'description' => esc_html__('End time (with buffer time)', 'motopress-appointment')
            ],
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        if (is_null($args['reservation'])) {
            return '';
        }

        $reservation = $args['reservation'];

        switch ($tag) {
            case 'reservation_id'         : return $reservation->id;
            case 'reservation_price'      : return mpa_tmpl_price($reservation->price);
            case 'reservation_date'       : return mpa_format_date($reservation->date);
            case 'reservation_time'       : return $reservation->serviceTime->toString();
            case 'reservation_buffer_time': return $reservation->bufferTime->toString();
            case 'start_time'             : return mpa_format_time($reservation->serviceTime->startTime);
            case 'end_time'               : return mpa_format_time($reservation->serviceTime->endTime);
            case 'start_buffer_time'      : return mpa_format_time($reservation->bufferTime->startTime);
            case 'end_buffer_time'        : return mpa_format_time($reservation->bufferTime->endTime);
        }

        return '';
    }
}
