<?php

namespace MotoPress\Appointment\Emails\Tags;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class ServiceTags extends AbstractTagsGroup
{
    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getName()
    {
        return 'service';
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getLabel()
    {
        return esc_html__('Service tags', 'motopress-appointment');
    }

    /**
     * @since 1.1.0
     */
    protected function setupTags()
    {
        $this->addTags([
            'service_id' => [
                'description' => esc_html__('Service ID', 'motopress-appointment')
            ],
            'service_name' => [
                'description' => esc_html__('Service name', 'motopress-appointment')
            ],
            'service_description' => [
                'description' => esc_html__('Service description', 'motopress-appointment')
            ],
            'service_categories' => [
                'description' => esc_html__('Service categories', 'motopress-appointment')
            ],
            'service_link' => [
                'description' => esc_html__('Service edit link', 'motopress-appointment')
            ]
        ]);
    }

    /**
     * @param string $tag
     * @param array $args
     * @param \MotoPress\Appointment\Emails\EmailTags $tagsControl
     * @param string $content
     *
     * @since 1.1.0
     */
    protected function replaceTag($tag, $args, $tagsControl, $content)
    {
        if (is_null($args['reservation'])) {
            return '';
        }

        $reservation = $args['reservation'];
        $service = mpa_get_service($reservation->serviceId);

        if (is_null($service)) {
            return '';
        }

        switch ($tag) {
            case 'service_id'         : return $service->id;
            case 'service_name'       : return $service->title;
            case 'service_description': return $service->description;
            case 'service_categories' : return implode(', ', mpa_get_service_categories($service->id, 'name'));
            case 'service_link'       : return mpa_tmpl_edit_post_link($service->id);
        }

        return '';
    }
}
