<?php

namespace MotoPress\Appointment\Emails\TemplateParts;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
abstract class AbstractTemplatePart
{
    /**
     * @since 1.1.0
     */
    public function __construct()
    {
        $this->addActions();
    }

    /**
     * @since 1.1.0
     */
    protected function addActions()
    {
        add_action('mpa_email_section_settings', [$this, 'filterSettings']);
    }

    /**
     * @param array $fields
     * @param string $section
     * @return array
     *
     * @access protected
     *
     * @since 1.1.0
     */
    public function filterSettings($fields, $section)
    {
        if ($section == $this->getName()) {
            $fields += $this->getFields();
        }

        return $fields;
    }

    /**
     * @return string
     *
     * @since 1.1.0
     */
    abstract public function getName();

    /**
     * @return string
     *
     * @since 1.1.0
     */
    abstract public function getLabel();

    /**
     * @return string
     *
     * @since 1.1.0
     */
    public function getDescription()
    {
        return '';
    }

    /**
     * @return array Array of args.
     *
     * @since 1.1.0
     */
    public function getFields()
    {
        $id = mpa_prefix($this->getName());

        $parentUrl = mpapp()->pages()->settings()->getUrl([
            'tab' => 'email'
        ]);

        return [
            "{$id}_group" => [
                'type'         => 'group',
                'label'        => $this->getLabel(),
                'description'  => $this->getDescription(),
                'title_actions'=> [
                    $parentUrl => esc_html__('Back', 'motopress-appointment')
                ]
            ],
            $id => [
                'type'         => 'rich-editor',
                'label'        => esc_html__('Template Content', 'motopress-appointment'),
                'description'  => mpapp()->emails()->getTemplatePartTags()->getTagsDescription(),
                'rows'         => 20,
                'default'      => $this->renderTemplate(),
                'translatable' => true
            ]
        ];
    }

    /**
     * @return string Rendered template.
     *
     * @since 1.1.0
     */
    abstract public function renderTemplate();
}
