<?php

namespace MotoPress\Appointment\Entities;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 *
 * @see \MotoPress\Appointment\Repositories\BookingRepository
 */
class Booking extends AbstractEntity
{
    /**
     * @var string
     *
     * @since 1.0
     */
    public $status = 'new';

    /**
     * @var float
     *
     * @since 1.0
     */
    public $totalPrice = 0.0;

    /**
     * @var Reservation[]
     *
     * @since 1.0
     */
    public $reservations = [];

    /**
     * @var Customer
     *
     * @since 1.0
     */
    public $customer = null;

    /**
     * @param array $args Optional.
     * @return array
     *
     * @see \MotoPress\Appointment\Repositories\AbstractRepository::findAll()
     *
     * @since 1.0
     */
    public function getServices($args = [])
    {
        return $this->getLinkedEntities($this->getServiceIds(), $args, 'mpa_get_services');
    }

    /**
     * @param array $args Optional.
     * @return array
     *
     * @see \MotoPress\Appointment\Repositories\AbstractRepository::findAll()
     *
     * @since 1.0
     */
    public function getEmployees($args = [])
    {
        return $this->getLinkedEntities($this->getEmployeeIds(), $args, 'mpa_get_employees');
    }

    /**
     * @param array $args Optional.
     * @return array
     *
     * @see \MotoPress\Appointment\Repositories\AbstractRepository::findAll()
     *
     * @since 1.0
     */
    public function getLocations($args = [])
    {
        return $this->getLinkedEntities($this->getLocationIds(), $args, 'mpa_get_locations');
    }

    /**
     * @param int[] $ids
     * @param array $args
     * @param string $getCallback
     * @return array
     *
     * @since 1.0
     */
    protected function getLinkedEntities($ids, $args, $getCallback)
    {
        if (empty($ids)) {
            return [];
        }

        $searchArgs = array_merge($args, ['include' => $ids]);

        // mpa_get_services($searchArgs) etc.
        return $getCallback($searchArgs);
    }

    /**
     * @return int[]
     *
     * @since 1.0
     */
    public function getServiceIds()
    {
        return $this->mapReservations('serviceId');
    }

    /**
     * @return int[]
     *
     * @since 1.0
     */
    public function getEmployeeIds()
    {
        return $this->mapReservations('employeeId');
    }

    /**
     * @return int[]
     *
     * @since 1.0
     */
    public function getLocationIds()
    {
        return $this->mapReservations('locationId');
    }

    /**
     * @param string $propertyName
     * @return array
     *
     * @since 1.0
     */
    public function mapReservations($propertyName)
    {
        return array_map(function ($reservation) use ($propertyName) {
            return $reservation->$propertyName;
        }, $this->reservations);
    }
}
