<?php

namespace MotoPress\Appointment\Entities;

use MotoPress\Appointment\Structures\Service\ServiceVariations;

if (!defined('ABSPATH')) {
	exit;
}

/**
 * @since 1.0
 * @see \MotoPress\Appointment\Repositories\ServiceRepository
 */
class Service extends AbstractEntity
{
	/**
	 * @since 1.0
	 * @var int[]
	 */
	public $employeeIds = [];

	/**
	 * @since 1.0
	 * @var string
	 */
	public $title = '';

	/**
	 * @since 1.0
	 * @var string
	 */
	public $description = '';

	/**
	 * @since 1.0
	 * @var float
	 */
	public $price = 0.0;

	/**
	 * Duration time in minutes.
	 *
	 * @since 1.0
	 * @var int
	 */
	public $duration = 0;

	/**
	 * Buffer time in minutes.
	 *
	 * @since 1.0
	 * @var int
	 */
	public $bufferTimeBefore = 0;

	/**
	 * Buffer time in minutes.
	 *
	 * @since 1.0
	 * @var int
	 */
	public $bufferTimeAfter = 0;

	/**
	 * Time in minutes.
	 *
	 * @since 1.0
	 * @var int
	 */
	public $timeBeforeBooking = 0;

	/**
	 * @since 1.0
	 * @var int
	 */
	public $minCapacity = 1;

	/**
	 * @since 1.0
	 * @var int
	 */
	public $maxCapacity = 1;

	/**
	 * @since 1.3.1
	 * @var bool
	 */
	public $allowGuests = false;

	/**
	 * @since 1.3.1
	 * @var bool
	 */
	public $multiplyPrice = false;

	/**
	 * @since 1.3.1
	 * @var ServiceVariations
	 */
	public $variations = [];

	/**
	 * @since 1.0
	 * @since 1.3.1 added the <code>$capacity</code> argument.
	 *
	 * @param int $employeeId Optional. 0 by default.
	 * @param int $capacity Optional. 0 by default (minimum capacity of the
	 *     service).
	 * @return float
	 */
	public function getPrice($employeeId = 0, $capacity = 0)
	{
		if (!$capacity) {
			$capacity = $this->minCapacity;
		}

		$price = $this->variations->getPrice($employeeId, $this->price);

		if ($this->multiplyPrice) {
			$price *= $capacity;
		}

		return $price;
	}

	/**
	 * @since 1.0
	 *
	 * @param int $employeeId Optional.
	 * @return int
	 */
	public function getDuration($employeeId = 0)
	{
		return $this->variations->getDuration($employeeId, $this->duration);
	}

	/**
	 * @since 1.3.1
	 *
	 * @param int $employeeId Optional.
	 * @return int
	 */
	public function getMinCapacity($employeeId = 0)
	{
		return $this->variations->getMinCapacity($employeeId, $this->minCapacity);
	}

	/**
	 * @since 1.3.1
	 *
	 * @param int $employeeId Optional.
	 * @return int
	 */
	public function getMaxCapacity($employeeId = 0)
	{
		return $this->variations->getMaxCapacity($employeeId, $this->maxCapacity);
	}

	/**
	 * @since 1.3.1
	 *
	 * @param int $employeeId Optional.
	 * @return int The maximum number of guests in range [0; ∞).
	 */
	public function getMaxGuests($employeeId = 0)
	{
		$maxCapacity = $this->getMaxCapacity($employeeId);
		$minCapacity = $this->getMinCapacity($employeeId);

		$maxGuests = $maxCapacity - $minCapacity;

		return max(0, $maxGuests);
	}
}
