<?php

namespace MotoPress\Appointment\Fields\Basic;

use MotoPress\Appointment\Fields\AbstractField;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class ChecklistField extends AbstractField
{
    /** @since 1.0 */
    const TYPE = 'checklist';

    /**
     * @var array
     *
     * @since 1.0
     */
    protected $options = [];

    /**
     * @var array
     *
     * @since 1.0
     */
    protected $default = [];

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function mapFields()
    {
        return array_merge(parent::mapFields(), [
            'options' => 'options'
        ]);
    }

    /**
     * @param mixed $value
     * @return mixed
     *
     * @since 1.0
     */
    protected function validateValue($value)
    {
        if ($value === '') {
            return $this->default;
        }

        $values = is_array($value) ? $value : [$value];
        $values = array_map('sanitize_text_field', $values);
        $values = mpa_evaluate_numbers($values); // If it's IDs, then convert it to ints
        $values = array_intersect($values, array_keys($this->options));
        $values = array_unique($values);

        return array_values($values); // Get rid of gaps in keys after array_unique()
    }

    /**
     * @return string
     *
     * @since 1.0
     */
    public function renderInput()
    {
        $output = '<input type="hidden" name="' . esc_attr($this->inputName) . '" value="">';

        foreach ($this->options as $value => $label) {
            $output .= '<label>';
                $inputAtts = $this->inputAtts($value);

                $output .= '<input' . mpa_tmpl_atts($inputAtts) . '>';
                $output .= '&nbsp;';
                $output .= esc_html($label);
            $output .= '</label>';
            $output .= '<br>';
        }

        return $output;
    }

    /**
     * @param string $currentItem Value of the current checkbox. Optional only
     *     for compatibility purposes.
     * @return array
     *
     * @since 1.0
     */
    protected function inputAtts($currentItem = null)
    {
        $inputAtts = array_merge(parent::inputAtts(), [
            'type'  => 'checkbox',
            'name'  => "{$this->inputName}[]",
            'id'    => "{$this->inputId}-{$currentItem}",
            'value' => $currentItem
        ]);

        if (in_array($currentItem, $this->value)) {
            $inputAtts['checked'] = 'checked';
        }

        return $inputAtts;
    }
}
