<?php

namespace MotoPress\Appointment\Fields\Basic;

use MotoPress\Appointment\Fields\AbstractField;
use MotoPress\Appointment\Utils\ValidateUtils;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class NumberField extends AbstractField
{
    /** @since 1.0 */
    const TYPE = 'number';

    /**
     * @var int|false
     *
     * @since 1.0
     */
    public $min = 0;

    /**
     * @var int|false
     *
     * @since 1.0
     */
    public $max = false;

    /**
     * @var int|false
     *
     * @since 1.0
     */
    public $step = 1;

    /**
     * @var int
     *
     * @since 1.0
     */
    protected $default = 0;

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function mapFields()
    {
        return array_merge(
            parent::mapFields(),
            [
                'min'  => 'min',
                'max'  => 'max',
                'step' => 'step'
            ]
        );
    }

    /**
     * @param mixed $value
     * @return mixed
     *
     * @since 1.0
     */
    protected function validateValue($value)
    {
        if ($value === '') {
            return $this->default;
        }

        $value = ValidateUtils::validateFloat($value, $this->min, $this->max);

        if ($value !== false) {
            return $value;
        } else {
            return $this->default;
        }
    }

    /**
     * @return string
     *
     * @since 1.0
     */
    public function renderInput()
    {
        return '<input' . mpa_tmpl_atts($this->inputAtts()) . '>';
    }

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function inputAtts()
    {
        return array_merge(
            parent::inputAtts(),
            [
                'type'  => 'number',
                'value' => $this->value
            ],
            $this->rangeAtts()
        );
    }

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function rangeAtts()
    {
        $atts = [];

        if ($this->min !== false) {
            $atts['min'] = $this->min;
        }

        if ($this->max !== false) {
            $atts['max'] = $this->max;
        }

        if ($this->step !== false) {
            $atts['step'] = $this->step;
        }

        return $atts;
    }
}
