<?php

namespace MotoPress\Appointment\ListTables\Emails;

use MotoPress\Appointment\Emails\AbstractEmail;
use MotoPress\Appointment\ListTables\AbstractListTable;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class EmailsListTable extends AbstractListTable
{
    /**
     * @since 1.1.0
     */
    protected function loadItems()
    {
        $this->items = mpapp()->emails()->getEmails();
    }

    /**
     * @return array
     *
     * @since 1.1.0
     */
    public function getColumns()
    {
        return [
            'label'      => esc_html_x('Email', 'Column "Email"', 'motopress-appointment'),
            'switch'     => esc_html__('Enabled', 'motopress-appointment'),
            'type'       => esc_html__('Content Type', 'motopress-appointment'),
            'recipients' => esc_html__('Recipients', 'motopress-appointment'),
            'actions'    => '' // No title
        ];
    }

    /**
     * @param string $columnName
     * @param AbstractEmail $email
     *
     * @since 1.1.0
     */
    protected function displayColumn($columnName, $email)
    {
        switch ($columnName) {
            case 'label':
                // Show label
                echo wp_kses_post( mpa_tmpl_link($this->getSectionUrl($email), $email->getLabel()) );

                // Show description
                $description = $email->getDescription();

                if (!empty($description)) {
                    echo '<p>', wp_kses_post( $description ), '</p>';
                }

                break;

            case 'switch':
                echo $email->isDisabled() ? esc_html__('No', 'motopress-appointment') : esc_html__('Yes', 'motopress-appointment');
                break;

            case 'type':
                echo 'text/html';
                break;

            case 'recipients':
                $recipients = $email->getRecipients();

                if (!empty($recipients)) {
                    echo wp_kses_post( $recipients );
                } else {
                    echo esc_html( mpa_tmpl_placeholder() );
                }

                break;

            case 'actions':
                $editUrl = $this->getSectionUrl($email);
                $buttonAtts = ['class' => 'button'];

                echo wp_kses_post( mpa_tmpl_link($editUrl, esc_html__('Manage', 'motopress-appointment'), $buttonAtts) );

                break;
        }
    }

    /**
     * @param AbstractEmail $email
     * @return string
     *
     * @since 1.1.0
     */
    protected function getSectionUrl($email)
    {
        return mpapp()->pages()->settings()->getUrl([
            'tab'     => 'email',
            'section' => $email->getName()
        ]);
    }
}
