<?php

namespace MotoPress\Appointment\Metaboxes\Schedule;

use MotoPress\Appointment\Metaboxes\FieldsMetabox;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class ScheduleSettingsMetabox extends FieldsMetabox
{
    /**
     * @return string
     *
     * @since 1.0
     */
    protected function theName()
    {
        return 'schedule_settings_metabox';
    }

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function theFields()
    {
        return [
            'employee' => [
                'type'        => 'select',
                'label'       => esc_html__('Employee', 'motopress-appointment'),
                'description' => esc_html__('To which employee this schedule applies.', 'motopress-appointment'),
                'options'     => mpa_no_value(0) + mpa_get_employees(),
                'default'     => 0
            ],
            'main_location' => [
                'type'        => 'select',
                'label'       => esc_html__('Main Location', 'motopress-appointment'),
                'description' => esc_html__('The location where the employee spends the major amount of time.', 'motopress-appointment'),
                'options'     => mpa_no_value(0) + mpa_get_locations(),
                'default'     => 0
            ]
        ];
    }

    /**
     * @param array $values [Postmeta name => [add, update, delete]]
     * @param int $postId
     * @param \WP_Post $post
     *
     * @since 1.0
     */
    protected function saveValues($values, $postId, $post)
    {
        parent::saveValues($values, $postId, $post);

        // Each employee may have only one schedule
        if (isset($values['update']['_mpa_employee'])) {
            $employeeId = $values['update']['_mpa_employee'];

            $schedules = mpapp()->repositories()->schedule()->findAllByEmployee($employeeId, [
                'exclude' => [$postId],
                'fields'  => 'ids',
            ]);

            foreach ($schedules as $scheduleId) {
                delete_post_meta($scheduleId, '_mpa_employee');
            }
        }
    }

    /**
     * @return string
     *
     * @since 1.0
     */
    public function getLabel()
    {
        return esc_html__('Schedule Settings', 'motopress-appointment');
    }
}
