<?php

namespace MotoPress\Appointment\Metaboxes\Service;

use MotoPress\Appointment\Metaboxes\FieldsMetabox;
use WP_Post;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class ServiceSettingsMetabox extends FieldsMetabox
{
    /**
     * @return string
     *
     * @since 1.0
     */
    protected function theName()
    {
        return 'service_settings_metabox';
    }

    /**
     * @return array
     *
     * @since 1.0
     */
    protected function theFields()
    {
        return [
            'price' => [
                'type'        => 'price',
                'label'       => esc_html__('Price', 'motopress-appointment')
            ],
            'duration' => [
                'type'        => 'duration',
                'label'       => esc_html__('Duration', 'motopress-appointment'),
                'default'     => mpa_time_step(),
                'size'        => 'mild'
            ],
            'buffer_time_before' => [
                'type'        => 'duration',
                'label'       => esc_html__('Buffer Time Before', 'motopress-appointment'),
                'description' => esc_html__('Time needed to get prepared for the appointment, when another booking for the same service and employee cannot be made.', 'motopress-appointment'),
                'size'        => 'mild'
            ],
            'buffer_time_after' => [
                'type'        => 'duration',
                'label'       => esc_html__('Buffer Time After', 'motopress-appointment'),
                'description' => esc_html__('Time after the appointment (rest, cleanup, etc.), when another booking for the same service and employee cannot be made.', 'motopress-appointment'),
                'size'        => 'mild'
            ],
            'time_before_booking' => [
                'type'        => 'duration',
                'label'       => esc_html__('Time Before Booking', 'motopress-appointment'),
                'description' => esc_html__('Minimum period before the appointment when customers can submit a booking request.', 'motopress-appointment'),
                'size'        => 'mild'
			],
			'min_capacity' => [
				'type'        => 'number',
				'label'       => esc_html__('Minimum Capacity', 'motopress-appointment'),
				'description' => esc_html__('Here you can set the minimum number of persons per one booking of this service.', 'motopress-appointment'),
				'min'         => 1,
				'default'     => 1,
				'size'        => 'small',
			],
			'max_capacity' => [
				'type'        => 'number',
				'label'       => esc_html__('Maximum Capacity', 'motopress-appointment'),
				'description' => esc_html__('Here you can set the maximum number of persons per one appointment.', 'motopress-appointment'),
				'min'         => 1,
				'default'     => 1,
				'size'        => 'small',
			],
			'allow_guests' => [
				'type'        => 'checkbox',
				'label'       => esc_html__('Allow Extra Clients', 'motopress-appointment'),
				'label2'      => esc_html__('Here you can choose whether you want to show or hide the “Bringing anyone with you?” option on the checkout form.', 'motopress-appointment'),
				'default'     => false,
			],
			'multiply_price' => [
				'type'        => 'checkbox',
				'label'       => esc_html__('Multiply Price', 'motopress-appointment'),
				'label2'      => esc_html__('Multiply price by the number of people.', 'motopress-appointment'),
				'default'     => false,
			],
        ];
    }

    /**
     * @return string
     *
     * @since 1.0
     */
    public function getLabel()
    {
        return esc_html__('Service Settings', 'motopress-appointment');
    }
}
