<?php

namespace MotoPress\Appointment\PostTypes\Statuses;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class BookingStatuses extends AbstractPostStatuses
{
    /** @since 1.0 */
    const STATUS_PENDING   = 'pending';

    /** @since 1.0 */
    const STATUS_CANCELLED = 'cancelled';

    /** @since 1.0 */
    const STATUS_ABANDONED = 'abandoned';

    /** @since 1.0 */
    const STATUS_CONFIRMED = 'confirmed';

    /**
     * @since 1.0
     */
    protected function initStatuses()
    {
        $this->statuses[self::STATUS_PENDING] = [
            'label'       => esc_html_x('Pending', 'Booking status', 'motopress-appointment'),
            // Translators: %s: The posts count.
            'label_count' => _n_noop('Pending <span class="count">(%s)</span>', 'Pending <span class="count">(%s)</span>', 'motopress-appointment'),
            'is_public'   => true,
            'is_internal' => false,
            'is_blocker'  => true,
            'is_manual'   => true
        ];

        $this->statuses[self::STATUS_CANCELLED] = [
            'label'       => esc_html_x('Cancelled', 'Booking status', 'motopress-appointment'),
            // Translators: %s: The posts count.
            'label_count' => _n_noop('Cancelled <span class="count">(%s)</span>', 'Cancelled <span class="count">(%s)</span>', 'motopress-appointment'),
            'is_public'   => true,
            'is_internal' => false,
            'is_blocker'  => false,
            'is_manual'   => true
        ];

        $this->statuses[self::STATUS_ABANDONED] = [
            'label'       => esc_html_x('Abandoned', 'Booking status', 'motopress-appointment'),
            // Translators: %s: The posts count.
            'label_count' => _n_noop('Abandoned <span class="count">(%s)</span>', 'Abandoned <span class="count">(%s)</span>', 'motopress-appointment'),
            'is_public'   => true,
            'is_internal' => false,
            'is_blocker'  => false,
            'is_manual'   => false
        ];

        $this->statuses[self::STATUS_CONFIRMED] = [
            'label'       => esc_html_x('Confirmed', 'Booking status', 'motopress-appointment'),
            // Translators: %s: The posts count.
            'label_count' => _n_noop('Confirmed <span class="count">(%s)</span>', 'Confirmed <span class="count">(%s)</span>', 'motopress-appointment'),
            'is_public'   => true,
            'is_internal' => false,
            'is_blocker'  => true,
            'is_manual'   => true
        ];
    }

    /**
     * @param string $newStatus
     * @param string $oldStatus
     * @param \MotoPress\Appointment\Entities\Booking $booking
     *
     * @since 1.0
     */
    protected function finishTransition($newStatus, $oldStatus, $booking)
    {
        // Add booking log
        $newLabel = $this->getLabel($newStatus);
        $oldLabel = $this->getLabel($oldStatus);

        // Translators: 1: Old status name (like "Pending"), 2: New status name.
        mpa_add_booking_log($booking, sprintf(esc_html__('Status changed from %1$s to %2$s.', 'motopress-appointment'), $oldLabel, $newLabel));
    }

    /**
     * @return array [Status => Label]
     *
     * @since 1.0
     */
    public function getPendingStatuses()
    {
        return $this->getLabels([
            self::STATUS_PENDING
        ]);
    }

    /**
     * @return array [Status => Label]
     *
     * @since 1.0
     */
    public function getFailedStatuses()
    {
        return $this->getLabels([
            self::STATUS_CANCELLED,
            self::STATUS_ABANDONED
        ]);
    }

    /**
     * @return array [Status => Label]
     *
     * @since 1.0
     */
    public function getBookedStatuses()
    {
        return $this->getLabels([
            self::STATUS_CONFIRMED
        ]);
    }
}
