<?php

namespace MotoPress\Appointment\Registries;

use MotoPress\Appointment\Metaboxes\Booking;
use MotoPress\Appointment\Metaboxes\Employee;
use MotoPress\Appointment\Metaboxes\Schedule;
use MotoPress\Appointment\Metaboxes\Service;
use MotoPress\Appointment\Metaboxes\Shortcode;
use MotoPress\Appointment\Metaboxes\AbstractMetabox;
use MotoPress\Appointment\Metaboxes\SubmitMetabox;
use MotoPress\Appointment\PostTypes;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class MetaboxesRegistry
{
    /**
     * @var AbstractMetabox[]
     *
     * @since 1.0
     */
    protected $metaboxes = [];

    /**
     * @return Employee\EmployeeContactsMetabox
     *
     * @since 1.2
     */
    public function employeeContacts()
    {
        if (!isset($this->metaboxes['employeeContacts'])) {
            $this->metaboxes['employeeContacts'] = new Employee\EmployeeContactsMetabox(PostTypes\EmployeePostType::POST_TYPE);
        }

        return $this->metaboxes['employeeContacts'];
    }

    /**
     * @return Employee\EmployeeSocialNetworksMetabox
     *
     * @since 1.2
     */
    public function employeeSocialNetworks()
    {
        if (!isset($this->metaboxes['employeeSocialNetworks'])) {
            $this->metaboxes['employeeSocialNetworks'] = new Employee\EmployeeSocialNetworksMetabox(PostTypes\EmployeePostType::POST_TYPE);
        }

        return $this->metaboxes['employeeSocialNetworks'];
    }

    /**
     * @return Employee\EmployeeAdditionalInfoMetabox
     *
     * @since 1.2
     */
    public function employeeAdditionalInfo()
    {
        if (!isset($this->metaboxes['employeeAdditionalInfo'])) {
            $this->metaboxes['employeeAdditionalInfo'] = new Employee\EmployeeAdditionalInfoMetabox(PostTypes\EmployeePostType::POST_TYPE);
        }

        return $this->metaboxes['employeeAdditionalInfo'];
    }

    /**
     * @return Schedule\ScheduleSettingsMetabox
     *
     * @since 1.0
     */
    public function scheduleSettings()
    {
        if (!isset($this->metaboxes['scheduleSettings'])) {
            $this->metaboxes['scheduleSettings'] = new Schedule\ScheduleSettingsMetabox(PostTypes\SchedulePostType::POST_TYPE);
        }

        return $this->metaboxes['scheduleSettings'];
    }

    /**
     * @return Schedule\ScheduleTimetableMetabox
     *
     * @since 1.0
     */
    public function scheduleTimetable()
    {
        if (!isset($this->metaboxes['scheduleTimetable'])) {
            $this->metaboxes['scheduleTimetable'] = new Schedule\ScheduleTimetableMetabox(PostTypes\SchedulePostType::POST_TYPE);
        }

        return $this->metaboxes['scheduleTimetable'];
    }

    /**
     * @return Schedule\ScheduleDaysOffMetabox
     *
     * @since 1.0
     */
    public function scheduleDaysOff()
    {
        if (!isset($this->metaboxes['scheduleDaysOff'])) {
            $this->metaboxes['scheduleDaysOff'] = new Schedule\ScheduleDaysOffMetabox(PostTypes\SchedulePostType::POST_TYPE);
        }

        return $this->metaboxes['scheduleDaysOff'];
    }

    /**
     * @return Schedule\ScheduleCustomWorkdaysMetabox
     *
     * @since 1.0
     */
    public function scheduleCustomWorkdays()
    {
        if (!isset($this->metaboxes['scheduleCustomWorkdays'])) {
            $this->metaboxes['scheduleCustomWorkdays'] = new Schedule\ScheduleCustomWorkdaysMetabox(PostTypes\SchedulePostType::POST_TYPE);
        }

        return $this->metaboxes['scheduleCustomWorkdays'];
    }

    /**
     * @return Service\ServiceSettingsMetabox
     *
     * @since 1.0
     */
    public function serviceSettings()
    {
        if (!isset($this->metaboxes['serviceSettings'])) {
            $this->metaboxes['serviceSettings'] = new Service\ServiceSettingsMetabox(PostTypes\ServicePostType::POST_TYPE);
        }

        return $this->metaboxes['serviceSettings'];
    }

    /**
     * @return Service\ServicePerformersMetabox
     *
     * @since 1.0
     */
    public function servicePerformers()
    {
        if (!isset($this->metaboxes['servicePerformers'])) {
            $this->metaboxes['servicePerformers'] = new Service\ServicePerformersMetabox(PostTypes\ServicePostType::POST_TYPE);
        }

        return $this->metaboxes['servicePerformers'];
    }

    /**
     * @return SubmitMetabox
     *
     * @since 1.0
     */
    public function bookingSubmit()
    {
        if (!isset($this->metaboxes['bookingSubmit'])) {
            $this->metaboxes['bookingSubmit'] = new SubmitMetabox(PostTypes\BookingPostType::POST_TYPE);
        }

        return $this->metaboxes['bookingSubmit'];
    }

    /**
     * @return Booking\BookingPriceMetabox
     *
     * @since 1.0
     */
    public function bookingPrice()
    {
        if (!isset($this->metaboxes['bookingPrice'])) {
            $this->metaboxes['bookingPrice'] = new Booking\BookingPriceMetabox(PostTypes\BookingPostType::POST_TYPE);
        }

        return $this->metaboxes['bookingPrice'];
    }

    /**
     * @return Booking\BookingCustomerMetabox
     *
     * @since 1.0
     */
    public function bookingCustomer()
    {
        if (!isset($this->metaboxes['bookingCustomer'])) {
            $this->metaboxes['bookingCustomer'] = new Booking\BookingCustomerMetabox(PostTypes\BookingPostType::POST_TYPE);
        }

        return $this->metaboxes['bookingCustomer'];
    }

    /**
     * @return Shortcode\AppointmentFormMetabox
     *
     * @since 1.2
     */
    public function appointmentForm()
    {
        if (!isset($this->metaboxes['appointmentForm'])) {
            $this->metaboxes['appointmentForm'] = new Shortcode\AppointmentFormMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'normal', 'high');
        }

        return $this->metaboxes['appointmentForm'];
    }

    /**
     * @return Shortcode\AppointmentFormLabelsMetabox
     *
     * @since 1.2
     */
    public function appointmentFormLabels()
    {
        if (!isset($this->metaboxes['appointmentFormLabels'])) {
            $this->metaboxes['appointmentFormLabels'] = new Shortcode\AppointmentFormLabelsMetabox(PostTypes\ShortcodePostType::POST_TYPE);
        }

        return $this->metaboxes['appointmentFormLabels'];
    }

    /**
     * @return Shortcode\AppointmentFormDefaultsMetabox
     *
     * @since 1.2
     */
    public function appointmentFormDefaults()
    {
        if (!isset($this->metaboxes['appointmentFormDefaults'])) {
            $this->metaboxes['appointmentFormDefaults'] = new Shortcode\AppointmentFormDefaultsMetabox(PostTypes\ShortcodePostType::POST_TYPE);
        }

        return $this->metaboxes['appointmentFormDefaults'];
    }

    /**
     * @return Shortcode\EmployeesListMetabox
     *
     * @since 1.2
     */
    public function employeesList()
    {
        if (!isset($this->metaboxes['employeesList'])) {
            $this->metaboxes['employeesList'] = new Shortcode\EmployeesListMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'normal', 'high');
        }

        return $this->metaboxes['employeesList'];
    }

    /**
     * @return Shortcode\LocationsListMetabox
     *
     * @since 1.2
     */
    public function locationsList()
    {
        if (!isset($this->metaboxes['locationsList'])) {
            $this->metaboxes['locationsList'] = new Shortcode\LocationsListMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'normal', 'high');
        }

        return $this->metaboxes['locationsList'];
    }

    /**
     * @return Shortcode\ServicesListMetabox
     *
     * @since 1.2
     */
    public function servicesList()
    {
        if (!isset($this->metaboxes['servicesList'])) {
            $this->metaboxes['servicesList'] = new Shortcode\ServicesListMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'normal', 'high');
        }

        return $this->metaboxes['servicesList'];
    }

    /**
     * @return Shortcode\ServiceCategoriesMetabox
     *
     * @since 1.2
     */
    public function serviceCategories()
    {
        if (!isset($this->metaboxes['serviceCategories'])) {
            $this->metaboxes['serviceCategories'] = new Shortcode\ServiceCategoriesMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'normal', 'high');
        }

        return $this->metaboxes['serviceCategories'];
    }

    /**
     * @return Shortcode\ShortcodeOrderMetabox
     *
     * @since 1.2
     */
    public function shortcodeOrder()
    {
        if (!isset($this->metaboxes['shortcodeOrder'])) {
            $this->metaboxes['shortcodeOrder'] = new Shortcode\ShortcodeOrderMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'advanced');
        }

        return $this->metaboxes['shortcodeOrder'];
    }

    /**
     * @return Shortcode\ShortcodeTermsOrderMetabox
     *
     * @since 1.2
     */
    public function shortcodeTermsOrder()
    {
        if (!isset($this->metaboxes['shortcodeTermsOrder'])) {
            $this->metaboxes['shortcodeTermsOrder'] = new Shortcode\ShortcodeTermsOrderMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'advanced');
        }

        return $this->metaboxes['shortcodeTermsOrder'];
    }

    /**
     * @return Shortcode\ShortcodeAdvancedMetabox
     *
     * @since 1.2
     */
    public function shortcodeAdvanced()
    {
        if (!isset($this->metaboxes['shortcodeAdvanced'])) {
            $this->metaboxes['shortcodeAdvanced'] = new Shortcode\ShortcodeAdvancedMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'advanced', 'low');
        }

        return $this->metaboxes['shortcodeAdvanced'];
    }

    /**
     * @return Shortcode\ShortcodeExampleMetabox
     *
     * @since 1.2
     */
    public function shortcodeExample()
    {
        if (!isset($this->metaboxes['shortcodeExample'])) {
            $this->metaboxes['shortcodeExample'] = new Shortcode\ShortcodeExampleMetabox(PostTypes\ShortcodePostType::POST_TYPE, 'side', 'high');
        }

        return $this->metaboxes['shortcodeExample'];
    }

    /**
     * @since 1.0
     */
    public function addListeners()
    {
        $employeeCpt  = mpa_unprefix(PostTypes\EmployeePostType::POST_TYPE);
        $scheduleCpt  = mpa_unprefix(PostTypes\SchedulePostType::POST_TYPE);
        $serviceCpt   = mpa_unprefix(PostTypes\ServicePostType::POST_TYPE);
        $bookingCpt   = mpa_unprefix(PostTypes\BookingPostType::POST_TYPE);
        $shortcodeCpt = mpa_unprefix(PostTypes\ShortcodePostType::POST_TYPE);

        add_action("mpa_edit_{$employeeCpt}_page_loaded",  [$this, 'registerEmployeeMetaboxes']);
        add_action("mpa_edit_{$scheduleCpt}_page_loaded",  [$this, 'registerScheduleMetaboxes']);
        add_action("mpa_edit_{$serviceCpt}_page_loaded",   [$this, 'registerServiceMetaboxes']);
        add_action("mpa_edit_{$bookingCpt}_page_loaded",   [$this, 'registerBookingMetaboxes']);
        add_action("mpa_edit_{$shortcodeCpt}_page_loaded", [$this, 'registerShortcodeMetaboxes']);
    }

    /**
     * @access protected
     *
     * @since 1.2
     */
    public function registerEmployeeMetaboxes()
    {
        $this->employeeContacts();
        $this->employeeSocialNetworks();
        $this->employeeAdditionalInfo();
    }

    /**
     * @access protected
     *
     * @since 1.0
     */
    public function registerScheduleMetaboxes()
    {
        $this->scheduleSettings();
        $this->scheduleTimetable();
        $this->scheduleDaysOff();
        $this->scheduleCustomWorkdays();
    }

    /**
     * @access protected
     *
     * @since 1.0
     */
    public function registerServiceMetaboxes()
    {
        $this->serviceSettings();
        $this->servicePerformers();
    }

    /**
     * @access protected
     *
     * @since 1.0
     */
    public function registerBookingMetaboxes()
    {
        $this->bookingSubmit();
        $this->bookingPrice();
        $this->bookingCustomer();
    }

    /**
     * @access protected
     *
     * @since 1.2
     */
    public function registerShortcodeMetaboxes()
    {
        // Appointment form
        $this->appointmentForm();
        $this->appointmentFormLabels();
        $this->appointmentFormDefaults();

        // Lists
        $this->employeesList();
        $this->locationsList();
        $this->servicesList();
        $this->serviceCategories();

        // Advanced metaboxes
        $this->shortcodeOrder();
        $this->shortcodeTermsOrder();
        $this->shortcodeAdvanced();

        // Other
        $this->shortcodeExample();
    }
}
