<?php

namespace MotoPress\Appointment\Registries;

use MotoPress\Appointment\PostTypes;
use MotoPress\Appointment\Repositories;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class RepositoriesRegistry
{
    /**
     * @var Repositories\AbstractRepository[]
     *
     * @since 1.0
     */
    protected $repositories = [];

    /**
     * @return Repositories\EmployeeRepository
     *
     * @since 1.0
     */
    public function employee()
    {
        if (!isset($this->repositories['employee'])) {
            $this->repositories['employee'] = new Repositories\EmployeeRepository(PostTypes\EmployeePostType::POST_TYPE);
        }

        return $this->repositories['employee'];
    }

    /**
     * @return Repositories\ScheduleRepository
     *
     * @since 1.0
     */
    public function schedule()
    {
        if (!isset($this->repositories['schedule'])) {
            $this->repositories['schedule'] = new Repositories\ScheduleRepository(PostTypes\SchedulePostType::POST_TYPE);
        }

        return $this->repositories['schedule'];
    }

    /**
     * @return Repositories\LocationRepository
     *
     * @since 1.0
     */
    public function location()
    {
        if (!isset($this->repositories['location'])) {
            $this->repositories['location'] = new Repositories\LocationRepository(PostTypes\LocationPostType::POST_TYPE);
        }

        return $this->repositories['location'];
    }

    /**
     * @return Repositories\ServiceRepository
     *
     * @since 1.0
     */
    public function service()
    {
        if (!isset($this->repositories['service'])) {
            $this->repositories['service'] = new Repositories\ServiceRepository(PostTypes\ServicePostType::POST_TYPE);
        }

        return $this->repositories['service'];
    }

    /**
     * @return Repositories\BookingRepository
     *
     * @since 1.0
     */
    public function booking()
    {
        if (!isset($this->repositories['booking'])) {
            $this->repositories['booking'] = new Repositories\BookingRepository(PostTypes\BookingPostType::POST_TYPE);
        }

        return $this->repositories['booking'];
    }

    /**
     * @return Repositories\ReservationRepository
     *
     * @since 1.0
     */
    public function reservation()
    {
        if (!isset($this->repositories['reservation'])) {
            $this->repositories['reservation'] = new Repositories\ReservationRepository(PostTypes\ReservationPostType::POST_TYPE);
        }

        return $this->repositories['reservation'];
    }

    /**
     * @param string $postType
     * @return Repositories\AbstractRepository|null
     *
     * @since 1.0
     */
    public function getByPostType($postType)
    {
        switch ($postType) {
            case PostTypes\EmployeePostType::POST_TYPE:     return $this->employee();
            case PostTypes\SchedulePostType::POST_TYPE:     return $this->schedule();
            case PostTypes\LocationPostType::POST_TYPE:     return $this->location();
            case PostTypes\ServicePostType::POST_TYPE:      return $this->service();
            case PostTypes\BookingPostType::POST_TYPE:      return $this->booking();
            case PostTypes\ReservationPostType::POST_TYPE:  return $this->reservation();
            default: return null;
        }
    }
}
