<?php

namespace MotoPress\Appointment\Registries;

use MotoPress\Appointment\REST\Controllers;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class RestRegistry
{
    /**
     * @var Controllers\AbstractRestController[]
     *
     * @since 1.0
     */
    protected $controllers = [];

    /**
     * @return Controllers\SettingsRestController
     *
     * @since 1.0
     */
    public function settings()
    {
        if (!isset($this->controllers['settings'])) {
            $this->controllers['settings'] = new Controllers\SettingsRestController();
        }

        return $this->controllers['settings'];
    }

    /**
     * @return Controllers\SchedulesRestController
     *
     * @since 1.0
     */
    public function schedule()
    {
        if (!isset($this->controllers['schedules'])) {
            $this->controllers['schedules'] = new Controllers\SchedulesRestController();
        }

        return $this->controllers['schedules'];
    }

    /**
     * @return Controllers\ServicesRestController
     *
     * @since 1.0
     */
    public function service()
    {
        if (!isset($this->controllers['services'])) {
            $this->controllers['services'] = new Controllers\ServicesRestController();
        }

        return $this->controllers['services'];
    }

    /**
     * @return Controllers\BookingsRestController
     *
     * @since 1.0
     */
    public function booking()
    {
        if (!isset($this->controllers['booking'])) {
            $this->controllers['booking'] = new Controllers\BookingsRestController();
        }

        return $this->controllers['booking'];
    }

    /**
     * @return Controllers\CalendarRestController
     *
     * @since 1.2.1
     */
    public function calendar()
    {
        if (!isset($this->controllers['calendar'])) {
            $this->controllers['calendar'] = new Controllers\CalendarRestController();
        }

        return $this->controllers['calendar'];
    }

    /**
     * @since 1.0
     */
    public function registerAll()
    {
        $this->settings()->registerRoutes();
        $this->schedule()->registerRoutes();
        $this->service()->registerRoutes();
        $this->booking()->registerRoutes();
        $this->calendar()->registerRoutes();
    }
}
