<?php

namespace MotoPress\Appointment\Registries;

use MotoPress\Appointment\Shortcodes;
use MotoPress\Appointment\Shortcodes\SingleEmployee as EmployeeShortcodes;
use MotoPress\Appointment\Views\ShortcodesView;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class ShortcodesRegistry
{
    /**
     * @var Shortcodes\AbstractShortcode[]
     *
     * @since 1.0
     */
    protected $shortcodes = [];

    /**
     * @return Shortcodes\AppointmentFormShortcode
     *
     * @since 1.0
     */
    public function appointmentForm()
    {
        if (!isset($this->shortcodes['appointmentForm'])) {
            $this->shortcodes['appointmentForm'] = new Shortcodes\AppointmentFormShortcode();

            ShortcodesView::getInstance()->addAppointmentFormActions();
        }

        return $this->shortcodes['appointmentForm'];
    }

    /**
     * @return Shortcodes\EmployeesListShortcode
     *
     * @since 1.2
     */
    public function employeesList()
    {
        if (!isset($this->shortcodes['employeesList'])) {
            $this->shortcodes['employeesList'] = new Shortcodes\EmployeesListShortcode();

            ShortcodesView::getInstance()->addEmployeesListActions();
        }

        return $this->shortcodes['employeesList'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeImageShortcode
     *
     * @since 1.2
     */
    public function employeeImage()
    {
        if (!isset($this->shortcodes['employeeImage'])) {
            $this->shortcodes['employeeImage'] = new EmployeeShortcodes\EmployeeImageShortcode();
        }

        return $this->shortcodes['employeeImage'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeTitleShortcode
     *
     * @since 1.2
     */
    public function employeeTitle()
    {
        if (!isset($this->shortcodes['employeeTitle'])) {
            $this->shortcodes['employeeTitle'] = new EmployeeShortcodes\EmployeeTitleShortcode();
        }

        return $this->shortcodes['employeeTitle'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeServicesListShortcode
     *
     * @since 1.2
     */
    public function employeeServiceList()
    {
        if (!isset($this->shortcodes['employeeServiceList'])) {
            $this->shortcodes['employeeServiceList'] = new EmployeeShortcodes\EmployeeServicesListShortcode();
        }

        return $this->shortcodes['employeeServiceList'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeScheduleShortcode
     *
     * @since 1.2
     */
    public function employeeSchedule()
    {
        if (!isset($this->shortcodes['employeeSchedule'])) {
            $this->shortcodes['employeeSchedule'] = new EmployeeShortcodes\EmployeeScheduleShortcode();
        }

        return $this->shortcodes['employeeSchedule'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeContentShortcode
     *
     * @since 1.2
     */
    public function employeeContent()
    {
        if (!isset($this->shortcodes['employeeContent'])) {
            $this->shortcodes['employeeContent'] = new EmployeeShortcodes\EmployeeContentShortcode();
        }

        return $this->shortcodes['employeeContent'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeContactsShortcode
     *
     * @since 1.2
     */
    public function employeeContacts()
    {
        if (!isset($this->shortcodes['employeeContacts'])) {
            $this->shortcodes['employeeContacts'] = new EmployeeShortcodes\EmployeeContactsShortcode();
        }

        return $this->shortcodes['employeeContacts'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeSocialNetworksShortcode
     *
     * @since 1.2
     */
    public function employeeSocialNetworks()
    {
        if (!isset($this->shortcodes['employeeSocialNetworks'])) {
            $this->shortcodes['employeeSocialNetworks'] = new EmployeeShortcodes\EmployeeSocialNetworksShortcode();
        }

        return $this->shortcodes['employeeSocialNetworks'];
    }

    /**
     * @return EmployeeShortcodes\EmployeeAdditionalInfoShortcode
     *
     * @since 1.2
     */
    public function employeeAdditionalInfo()
    {
        if (!isset($this->shortcodes['employeeAdditionalInfo'])) {
            $this->shortcodes['employeeAdditionalInfo'] = new EmployeeShortcodes\EmployeeAdditionalInfoShortcode();
        }

        return $this->shortcodes['employeeAdditionalInfo'];
    }

    /**
     * @return Shortcodes\LocationsListShortcode
     *
     * @since 1.2
     */
    public function locationsList()
    {
        if (!isset($this->shortcodes['locationsList'])) {
            $this->shortcodes['locationsList'] = new Shortcodes\LocationsListShortcode();

            ShortcodesView::getInstance()->addLocationsListActions();
        }

        return $this->shortcodes['locationsList'];
    }

    /**
     * @return Shortcodes\ServicesListShortcode
     *
     * @since 1.2
     */
    public function servicesList()
    {
        if (!isset($this->shortcodes['servicesList'])) {
            $this->shortcodes['servicesList'] = new Shortcodes\ServicesListShortcode();

            ShortcodesView::getInstance()->addServicesListActions();
        }

        return $this->shortcodes['servicesList'];
    }

    /**
     * @return Shortcodes\ServiceCategoriesShortcode
     *
     * @since 1.2
     */
    public function serviceCategories()
    {
        if (!isset($this->shortcodes['serviceCategories'])) {
            $this->shortcodes['serviceCategories'] = new Shortcodes\ServiceCategoriesShortcode();

            ShortcodesView::getInstance()->addServiceCategoriesActions();
        }

        return $this->shortcodes['serviceCategories'];
    }

    /**
     * @since 1.0
     */
    public function registerAll()
    {
        $this->getShortcodes();
    }

    /**
     * @param string|string[] $shortcode One or more names.
     * @return Shortcodes\AbstractShortcode|Shortcodes\AbstractShortcode[]|null
     *
     * @since 1.3
     */
    public function getShortcodeByName($shortcode)
    {
        $shortcodes = [];

        foreach((array)$shortcode as $shortcodeName) {
            $methodName = mpa_str_to_method_name(mpa_unprefix($shortcodeName));

            if (method_exists($this, $methodName)) {
                $instance = $this->$methodName();

                $shortcodes[$instance->getName()] = $instance;
            }
        }

        if (!is_array($shortcode)) {
            if (!empty($shortcodes)) {
                return reset($shortcodes);
            } else {
                return null;
            }
        } else {
            return $shortcodes;
        }
    }

    /**
     * @return Shortcodes\AbstractShortcode[] All available shortcodes.
     *
     * @since 1.2
     */
    public function getShortcodes()
    {
        return [
            $this->appointmentForm(),

            // Lists
            $this->employeesList(),
            $this->locationsList(),
            $this->servicesList(),
            $this->serviceCategories(),

            // Single employee
            $this->employeeImage(),
            $this->employeeTitle(),
            $this->employeeServiceList(),
            $this->employeeSchedule(),
            $this->employeeContent(),
            $this->employeeContacts(),
            $this->employeeSocialNetworks(),
            $this->employeeAdditionalInfo()
        ];
    }

    /**
     * @return Shortcodes\AbstractShortcode[] Shortcodes that have their Edit Shortcode Page.
     *
     * @since 1.2
     */
    public function getPostShortcodes()
    {
        return [
            $this->appointmentForm(),

            // Lists
            $this->employeesList(),
            $this->locationsList(),
            $this->servicesList(),
            $this->serviceCategories()
        ];
    }

    /**
     * @param string|string[] Optional. One or more shortcode names. All
     *     shortcodes by default.
     * @return array
     *
     * @since 1.3
     */
    public function getShortcodeDetails($shortcode = '')
    {
        if (empty($shortcode)) {
            $shortcodes = $this->getShortcodes();
        } else {
            $shortcodes = $this->getShortcodeByName((array)$shortcode);
        }

        $details = [];

        foreach ($shortcodes as $shortcode) {
            // Notice: return value of getShortcodes() has numeric indexes
            $details[$shortcode->getName()] = [
                'label'      => $shortcode->getLabel(),
                'attributes' => $shortcode->getAttributes()
            ];
        }

        return $details;
    }
}
