<?php

namespace MotoPress\Appointment\Registries;

use MotoPress\Appointment\Emails\TemplateParts;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.1.0
 */
class TemplatesRegistry
{
    /**
     * @var array
     *
     * @since 1.1.0
     */
    protected $templates = [];

    /**
     * @return TemplateParts\AdminReservationDetailsTemplatePart
     *
     * @since 1.1.0
     */
    public function adminReservationDetails()
    {
        if (!isset($this->templates['adminReservationDetails'])) {
            $this->templates['adminReservationDetails'] = new TemplateParts\AdminReservationDetailsTemplatePart();
        }

        return $this->templates['adminReservationDetails'];
    }

    /**
     * @return TemplateParts\CustomerReservationDetailsTemplatePart
     *
     * @since 1.1.0
     */
    public function customerReservationDetails()
    {
        if (!isset($this->templates['customerReservationDetails'])) {
            $this->templates['customerReservationDetails'] = new TemplateParts\CustomerReservationDetailsTemplatePart();
        }

        return $this->templates['customerReservationDetails'];
    }

    /**
     * @return TemplateParts\AbstractTemplatePart[]
     *
     * @since 1.1.0
     */
    public function getEmailTemplateParts()
    {
        $templateParts = [
            $this->adminReservationDetails(),
            $this->customerReservationDetails()
        ];

        $templateParts = $this->mapByName($templateParts);

        /** @since 1.1.0 */
        $templateParts = apply_filters('mpa_email_template_parts', $templateParts);

        return $templateParts;
    }

    /**
     * @param string $name
     * @return TemplateParts\AbstractTemplatePart|null
     *
     * @since 1.1.0
     */
    public function getEmailTemplatePartByName($name) // 'admin_reservation_details'
    {
        $entryId = mpa_str_to_method_name($name);     // 'adminReservationDetails'

        // Get template part
        if (method_exists($this, $entryId)) {
            $entry = $this->$entryId();

            if ($entry instanceof TemplateParts\AbstractTemplatePart) {
                return $entry;
            } else {
                return null;
            }
        } else {
            return null;
        }
    }

    /**
     * @param TemplateParts\AbstractTemplatePart[] $entries [Entry ID => AbstractTemplatePart]
     * @return TemplateParts\AbstractTemplatePart[] [Entry name => AbstractTemplatePart]
     *
     * @since 1.1.0
     */
    protected function mapByName($entries)
    {
        $mapped = [];

        foreach ($entries as $entry) {
            $mapped[$entry->getName()] = $entry;
        }

        return $mapped;
    }
}
