<?php

namespace MotoPress\Appointment\Repositories;

use MotoPress\Appointment\Entities\Booking;
use MotoPress\Appointment\Entities\Customer;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 *
 * @see Booking
 */
class BookingRepository extends AbstractRepository
{
    /**
     * @return array
     *
     * @since 1.0
     */
    protected function entitySchema()
    {
        return [
            'post'     => ['ID', 'post_status'],
            'postmeta' => [
                '_mpa_total_price'    => true,
                '_mpa_customer_name'  => true,
                '_mpa_customer_email' => true,
                '_mpa_customer_phone' => true
            ]
        ];
    }

    /**
     * @param array $postData
     * @return Booking
     *
     * @since 1.0
     */
    protected function mapPostDataToEntity($postData)
    {
        $id = (int)$postData['ID'];

        $customerFields = [
            'name'  => $postData['customer_name'],
            'email' => $postData['customer_email'],
            'phone' => $postData['customer_phone']
        ];

        $fields = [
            'status'       => $postData['post_status'],
            'totalPrice'   => (float)$postData['total_price'],
            'reservations' => mpapp()->repositories()->reservation()->findAllByBooking($id),
            'customer'     => new Customer($id, $customerFields)
        ];

        return new Booking($id, $fields);
    }

    /**
     * @param int|Booking $booking
     * @param string $message
     * @param int $author Optional. Null by default.
     * @return int|false The new comment's ID on success, false on failure.
     *
     * @since 1.0
     */
    public function addLog($booking, $message, $author = null)
    {
        $bookingId = is_int($booking) ? $booking : $booking->id;

        if (is_null($author)) {
            $author = is_admin() ? get_current_user_id() : 0;
        }

        $commentData = [
            'comment_post_ID'  => $bookingId,
            'comment_content'  => $message,
            'user_id'          => $author,
            'comment_date'     => current_time('mysql'),
            'comment_date_gmt' => current_time('mysql', get_option('gmt_offset')),
            'comment_approved' => 1,
            'comment_type'     => 'mpa_booking_log'
        ];

        return wp_insert_comment($commentData);
    }
}
