<?php

namespace MotoPress\Appointment\Shortcodes;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.0
 */
class AppointmentFormShortcode extends AbstractPostShortcode
{
    /**
     * @return string
     *
     * @since 1.0
     */
    public function getName()
    {
        return 'appointment_form';
    }

    /**
     * @return string
     *
     * @since 1.2
     */
    public function getLabel()
    {
        return esc_html__('Appointment Form', 'motopress-appointment');
    }

    /**
     * @return array
     *
     * @since 1.2
     */
    public function getAttributes()
    {
        $appointmentFormAtts = [
            'show_category' => [
                'type'          => 'bool',
                'description'   => esc_html__('Show the service category field in the form.', 'motopress-appointment'),
                'default'       => true
            ],
            'show_location' => [
                'type'          => 'bool',
                'description'   => esc_html__('Show the location field in the form.', 'motopress-appointment'),
                'default'       => true
            ],
            'show_employee' => [
                'type'          => 'bool',
                'description'   => esc_html__('Show the employee field in the form.', 'motopress-appointment'),
                'default'       => true
            ],
            'label_category' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the service category field.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('Service Category', 'motopress-appointment')
            ],
            'label_service' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the service field.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('Service', 'motopress-appointment')
            ],
            'label_location' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the location field.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('Location', 'motopress-appointment')
            ],
            'label_employee' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the employee field.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('Employee', 'motopress-appointment')
            ],
            'label_unselected' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the unselected service field.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('— Select —', 'motopress-appointment')
            ],
            'label_option' => [
                'type'          => 'string',
                'description'   => esc_html__('Custom label for the unselected service category, location and employee fields.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => esc_html__('— Any —', 'motopress-appointment')
            ],
            'default_category' => [
                'type'          => 'string',
                'description'   => esc_html__('Slug of the selected service category.', 'motopress-appointment'),
                'default'       => '',
                'default_label' => null
            ],
            'default_service' => [
                'type'          => 'integer',
                'description'   => esc_html__('ID of the selected service.', 'motopress-appointment'),
                'default'       => 0,
                'default_label' => null
            ],
            'default_location' => [
                'type'          => 'integer',
                'description'   => esc_html__('ID of the selected location.', 'motopress-appointment'),
                'default'       => 0,
                'default_label' => null
            ],
            'default_employee' => [
                'type'          => 'integer',
                'description'   => esc_html__('ID of the selected employee.', 'motopress-appointment'),
                'default'       => 0,
                'default_label' => null
            ]
        ];

        return $appointmentFormAtts + parent::getAttributes();
    }

    /**
     * @param array $args
     * @param string $content
     * @param string $shortcodeTag
     * @return string
     *
     * @since 1.0
     */
    public function renderContent($args, $content, $shortcodeTag)
    {
        if (!is_admin()) {
            mpa_assets()->enqueueBundle('mpa-public');
        }

        return mpa_render_template('shortcodes/appointment-form.php', $args);
    }

    /**
     * @param array $validArgs
     * @param array $postArgs Source values.
     * @return array
     *
     * @since 1.2
     */
    protected function filterPostArgs($validArgs, $postArgs)
    {
        $filteredArgs = parent::filterPostArgs($validArgs, $postArgs);

        // Add show_* parameters
        if (isset($postArgs['show_items']) && is_array($postArgs['show_items'])) {
            $filteredArgs += [
                'show_category' => in_array('category', $postArgs['show_items']),
                'show_location' => in_array('location', $postArgs['show_items']),
                'show_employee' => in_array('employee', $postArgs['show_items'])
            ];
        }

        return $filteredArgs;
    }
}
