<?php

namespace MotoPress\Appointment\Widgets;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * @since 1.3
 */
class AppointmentFormWidget extends AbstractWidget
{
    /**
     * @return string
     *
     * @since 1.3
     */
    public function getId()
    {
        return 'appointment_form';
    }

    /**
     * @return string
     *
     * @since 1.3
     */
    public function getName()
    {
        return esc_html__('Appointment Form', 'motopress-appointment');
    }

    /**
     * @param array $instanceArgs
     * @param WP_Widget $widget The widget instance.
     * @return array
     *
     * @since 1.3
     */
    public function filterArgs($instanceArgs, $widget)
    {
        if ($widget === $this) {
            $instanceArgs = parent::filterArgs($instanceArgs, $widget);

            // Remove default values
            $instanceArgs = array_filter($instanceArgs);

            // Add "show_*" parameters
            foreach (['category', 'location', 'employee'] as $item) {
                $instanceArgs["show_{$item}"] = in_array($item, $instanceArgs['show_items']);
            }

            unset($instanceArgs['show_items']);
        }

        return $instanceArgs;
    }

    /**
     * @param array $instanceArgs Saved parameters from the database.
     * @return string
     *
     * @since 1.3
     */
    protected function renderContent($instanceArgs)
    {
        if (!is_admin()) {
            mpa_assets()->enqueueBundle('mpa-public');
        }

        return mpa_render_template('widgets/appointment-form.php', $instanceArgs);
    }

    /**
     * @return array
     *
     * @since 1.3
     */
    protected function getFields()
    {
        $unselectedSlug = ['' => esc_html__('— Unselected —', 'motopress-appointment')];
        $unselectedId   = [0  => esc_html__('— Unselected —', 'motopress-appointment')];

        return [
            'title' => [
                'type'        => 'text',
                'label'       => esc_html__('Title', 'motopress-appointment'),
                'default'     => esc_html__('Appointment Form', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'show_items' => [
                'type'        => 'checklist',
                'label'       => esc_html__('Show Items', 'motopress-appointment'),
                'options'     => [
                    'category'    => esc_html__('Service Category', 'motopress-appointment'),
                    'location'    => esc_html__('Location', 'motopress-appointment'),
                    'employee'    => esc_html__('Employee', 'motopress-appointment')
                ],
                'value'       => ['category', 'location', 'employee']
            ],

            'labels_group' => [
                'type'        => 'group',
                'label'       => esc_html__('Labels', 'motopress-appointment')
            ],
            'label_category' => [
                'type'        => 'text',
                'label'       => esc_html__('Service Category', 'motopress-appointment'),
                'placeholder' => esc_html__('Service Category', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'label_service' => [
                'type'        => 'text',
                'label'       => esc_html__('Service', 'motopress-appointment'),
                'placeholder' => esc_html__('Service', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'label_location' => [
                'type'        => 'text',
                'label'       => esc_html__('Location', 'motopress-appointment'),
                'placeholder' => esc_html__('Location', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'label_employee' => [
                'type'        => 'text',
                'label'       => esc_html__('Employee', 'motopress-appointment'),
                'placeholder' => esc_html__('Employee', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'label_unselected' => [
                'type'        => 'text',
                'label'       => esc_html__('Unselected Service', 'motopress-appointment'),
                'description' => esc_html__('Custom label for the unselected service field.', 'motopress-appointment'),
                'placeholder' => esc_html__('— Select —', 'motopress-appointment'),
                'size'        => 'wide'
            ],
            'label_option' => [
                'type'        => 'text',
                'label'       => esc_html__('Unselected Option', 'motopress-appointment'),
                'description' => esc_html__('Custom label for the unselected service category, location and employee fields.', 'motopress-appointment'),
                'placeholder' => esc_html__('— Any —', 'motopress-appointment'),
                'size'        => 'wide'
            ],

            'defaults_group' => [
                'type'        => 'group',
                'label'       => esc_html__('Default Values', 'motopress-appointment')
            ],
            'default_category' => [
                'type'        => 'select',
                'label'       => esc_html__('Service Category', 'motopress-appointment'),
                'options'     => $unselectedSlug + mpa_get_service_categories(),
                'size'        => 'wide'
            ],
            'default_service' => [
                'type'        => 'select',
                'label'       => esc_html__('Service', 'motopress-appointment'),
                'options'     => $unselectedId + mpa_get_services(),
                'size'        => 'wide'
            ],
            'default_location' => [
                'type'        => 'select',
                'label'       => esc_html__('Location', 'motopress-appointment'),
                'options'     => $unselectedId + mpa_get_locations(),
                'size'        => 'wide'
            ],
            'default_employee' => [
                'type'        => 'select',
                'label'       => esc_html__('Employee', 'motopress-appointment'),
                'options'     => $unselectedId + mpa_get_employees(),
                'size'        => 'wide'
            ],

            'advanced_group' => [
                'type'        => 'group',
                'label'       => esc_html__('Advanced', 'motopress-appointment')
            ],
            'html_id' => [
                'type'        => 'text',
                'label'       => esc_html__('HTML Anchor', 'motopress-appointment'),
                'description' => mpa_kses_link(__('HTML Anchor. Anchors lets you link directly to a section on a page. <a href="https://wordpress.org/support/article/page-jumps/" target="_blank">Learn more about anchors.</a>', 'motopress-appointment')),
                'size'        => 'wide'
            ],
            'html_class' => [
                'type'        => 'text',
                'label'       => esc_html__('CSS Class(es)', 'motopress-appointment'),
                'description' => esc_html__('Additional CSS Class(es). Separate multiple classes with spaces.', 'motopress-appointment'),
                'size'        => 'wide'
            ]
        ];
    }
}
