<?php

/**
 * @param string $template_name Optional. Full shortcode name. 'appointment_form' by default.
 * @param string $html_id       Optional. Unique ID of the shortcode instance.
 *
 * @since 1.0
 */

if (!defined('ABSPATH')) {
    exit;
}

// Initialize args
extract(
    [
        'template_name' => 'appointment_form',
        'html_id'       => ''
    ],
    EXTR_SKIP
);

if (empty($html_id)) {
	$html_id = uniqid();
}

/**
 * @param string $placeholder
 *
 * @since 1.0
 */
$placeholderName = apply_filters("{$template_name}_shortcode_name_placeholder", esc_html__('Name', 'motopress-appointment'));

/**
 * @param string $placeholder
 *
 * @since 1.0
 */
$placeholderEmail = apply_filters("{$template_name}_shortcode_email_placeholder", esc_html__('Email', 'motopress-appointment'));

/**
 * @param string $placeholder
 *
 * @since 1.0
 */
$placeholderPhone = apply_filters("{$template_name}_shortcode_phone_placeholder", esc_html__('Phone', 'motopress-appointment'));

// Display template
?>
<div class="mpa-booking-step mpa-booking-step-checkout mpa-hide">
    <form class="mpa-checkout-form" method="POST" action="">
        <section class="mpa-customer-details">
            <p class="mpa-shortcode-title">
                <?php esc_html_e('Your Information', 'motopress-appointment'); ?>
            </p>

            <p class="mpa-required-tip">
                <?php echo mpa_tmpl_required_tip(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped?>
            </p>

            <p class="mpa-input-wrapper mpa-customer-name-wrapper">
                <label for="mpa-customer-name-<?php echo esc_attr($html_id); ?>">
                    <?php esc_html_e('Name', 'motopress-appointment'); ?>
                    <?php echo mpa_tmpl_required(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                </label>

                <input
                    id="mpa-customer-name-<?php echo esc_attr($html_id); ?>"
                    class="mpa-customer-name"
                    type="text"
                    name="name"
                    placeholder="<?php echo esc_attr( $placeholderName ); ?>"
                    required="required">
            </p>

            <p class="mpa-input-wrapper mpa-customer-email-wrapper">
                <label for="mpa-customer-email-<?php echo esc_attr($html_id); ?>">
                    <?php esc_html_e('Email', 'motopress-appointment'); ?>
                    <?php echo mpa_tmpl_required(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                </label>

                <input
                    id="mpa-customer-email-<?php echo esc_attr($html_id); ?>"
                    class="mpa-customer-email"
                    type="email"
                    name="email"
                    placeholder="<?php echo esc_attr( $placeholderEmail ); ?>"
                    required="required">
            </p>

            <p class="mpa-input-wrapper mpa-customer-phone-wrapper">
                <label for="mpa-customer-phone-<?php echo esc_attr($html_id); ?>">
                    <?php esc_html_e('Phone', 'motopress-appointment'); ?>
                    <?php echo mpa_tmpl_required(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                </label>

                <input
                    id="mpa-customer-phone-<?php echo esc_attr($html_id); ?>"
                    class="mpa-customer-phone"
                    type="tel"
                    name="tel"
                    pattern="[0-9]+"
                    placeholder="<?php echo esc_attr( $placeholderPhone ); ?>"
                    required="required"
                >

                <span class="mpa-description mpa-small-description">
                    <?php esc_html_e('Format: 1234567890', 'motopress-appointment'); ?>
                </span>
            </p>
        </section>

		<section class="mpa-order-details">
			<p class="mpa-shortcode-title">
				<?php esc_html_e('Your Order', 'motopress-appointment'); ?>
			</p>

			<div class="mpa-order"></div>
		</section>

        <p class="mpa-actions">
            <?php echo mpa_tmpl_button(esc_html__('Back', 'motopress-appointment'), ['class' => 'button button-secondary mpa-button-back']); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
            <?php echo mpa_tmpl_button(esc_html__('Reserve', 'motopress-appointment'), ['class' => 'button button-primary mpa-button-next', 'type' => 'submit', 'disabled' => 'disabled']); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
        </p>
    </form>
</div>
